| Title: | Analysis of Visual Meteor Data |
|---|---|
| Description: | Provides a suite of analytical functionalities to process and analyze visual meteor observations from the Visual Meteor Database of the International Meteor Organization <https://www.imo.net/>. |
| Authors: | Janko Richter [aut, cre] |
| Maintainer: | Janko Richter <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 3.0.1 |
| Built: | 2026-05-20 13:45:23 UTC |
| Source: | https://github.com/jankorichter/vismeteor |